@@ -9,7 +9,6 @@ import (
 
 	"strings"
 
-	"github.com/hofstadter-io/hof/script/runtime"
 	"github.com/spf13/cobra"
 
 	"github.com/hofstadter-io/hof/cmd/hof/flags"
@@ -33,7 +32,7 @@ func RootPersistentPreRun(args []string) (err error) {
 
 func RootPersistentPostRun(args []string) (err error) {
 
-	WaitPrintUpdateAvailable()
+	// WaitPrintUpdateAvailable()
 
 	return err
 }
@@ -123,6 +122,7 @@ func RootInit() {
 
 	RootCmd.AddCommand(CompletionCmd)
 
+	RootCmd.AddCommand(CreateCmd)
 	RootCmd.AddCommand(DatamodelCmd)
 	RootCmd.AddCommand(GenCmd)
 	RootCmd.AddCommand(FlowCmd)
@@ -130,9 +130,6 @@ func RootInit() {
 	RootCmd.AddCommand(ModCmd)
 	RootCmd.AddCommand(RunCmd)
 	RootCmd.AddCommand(FeedbackCmd)
-	RootCmd.AddCommand(HackCmd)
-	RootCmd.AddCommand(GebCmd)
-	RootCmd.AddCommand(LogoCmd)
 
 }
 
@@ -172,15 +169,6 @@ func RunErr() error {
 	return RootCmd.Execute()
 }
 
-func CallTS(ts *runtime.Script, args []string) error {
-	RootCmd.SetArgs(args)
-
-	err := RootCmd.Execute()
-	ts.Check(err)
-
-	return err
-}
-
 const RootCustomHelp = `hof - the high code framework
 
   Learn more at https://docs.hofstadter.io
@@ -189,6 +177,7 @@ Usage:
   hof [flags] [command] [args]
 
 Main commands:
+  create                bootstrap projects, components, and files from any git repo
   datamodel             manage, diff, and migrate your data models
   gen                   modular and composable code gen: CUE & data + templates = _
   flow                  run CUE pipelines with the hof/flow DAG engine
