@@ -14,6 +14,8 @@ import (
 	"github.com/parnurzeal/gorequest"
 	"github.com/spf13/cobra"
 
+	"github.com/hofstadter-io/hof/cmd/hof/ga"
+
 	"github.com/hofstadter-io/hof/cmd/hof/verinfo"
 )
 
@@ -55,6 +57,8 @@ var UpdateCmd = &cobra.Command{
 
 	PreRun: func(cmd *cobra.Command, args []string) {
 
+		ga.SendCommandPath("update")
+
 	},
 
 	Run: func(cmd *cobra.Command, args []string) {
@@ -66,7 +70,7 @@ var UpdateCmd = &cobra.Command{
 		}
 
 		// Semver Check?
-		cur := ProgramVersion{Version: "v" + verinfo.Version}
+		cur := ProgramVersion{Version: verinfo.Version}
 		if latest.Version == cur.Version || (UpdateVersionFlag == "" && cur.Version == "vLocal") {
 			return
 		} else {
@@ -85,13 +89,26 @@ var UpdateCmd = &cobra.Command{
 }
 
 func init() {
-	go CheckUpdate(false)
+	// disable automatic update checks
+	// go CheckUpdate(false)
 
 	help := UpdateCmd.HelpFunc()
 	usage := UpdateCmd.UsageFunc()
 
-	UpdateCmd.SetHelpFunc(help)
-	UpdateCmd.SetUsageFunc(usage)
+	thelp := func(cmd *cobra.Command, args []string) {
+		if UpdateCmd.Name() == cmd.Name() {
+			ga.SendCommandPath("update help")
+		}
+		help(cmd, args)
+	}
+	tusage := func(cmd *cobra.Command) error {
+		if UpdateCmd.Name() == cmd.Name() {
+			ga.SendCommandPath("update usage")
+		}
+		return usage(cmd)
+	}
+	UpdateCmd.SetHelpFunc(thelp)
+	UpdateCmd.SetUsageFunc(tusage)
 
 }
 
@@ -313,7 +330,7 @@ func downloadAndInstall(url string) error {
 		return err
 	}
 
-	// defer os.Remove(tmpfile.Name()) // clean up
+	defer os.Remove(tmpfile.Name()) // clean up
 
 	if _, err := tmpfile.Write(content); err != nil {
 		return err
@@ -332,8 +349,10 @@ func downloadAndInstall(url string) error {
 		return err
 	}
 
-	// Sudo copy the file
-	cmdStr := fmt.Sprintf("export OWNER=$(ls -l %s | awk '{ print $3 \":\" $4 }') && sudo mv %s %s-v%s && sudo cp %s %s && sudo chown $OWNER %s && sudo chmod 0755 %s",
+	// TODO (hof/update) replace current binary swap with something better
+	// either a straightup file write or a golang package that handles binary updates already (there's at least 1)
+	// copy the file
+	cmdStr := fmt.Sprintf("export OWNER=$(ls -l %s | awk '{ print $3 \":\" $4 }') && mv %s %s-v%s && cp %s %s && chown $OWNER %s && chmod 0755 %s",
 		real,                        // get owner
 		real, real, verinfo.Version, // backup
 		tmpfile.Name(), real, // cp
@@ -363,4 +382,4 @@ func downloadAndInstall(url string) error {
 	UpdateAvailable = nil
 	UpdateData = nil
 	return nil
-}
\ No newline at end of file
+}
