@@ -7,12 +7,18 @@ import (
 	"github.com/hofstadter-io/hof/script/runtime"
 )
 
+func envSetup(env *runtime.Env) error {
+	env.Vars = append(env.Vars, "HOF_TELEMETRY_DISABLED=1")
+	return nil
+}
+
 func TestAPIFlow(t *testing.T) {
 	yagu.Mkdir(".workdir/tasks/api")
 	runtime.Run(t, runtime.Params{
 		Dir:         "testdata/tasks/api",
 		Glob:        "*.txt",
 		WorkdirRoot: ".workdir/tasks/api",
+		Setup:       envSetup,
 	})
 }
 
@@ -22,6 +28,7 @@ func TestGenFlow(t *testing.T) {
 		Dir:         "testdata/tasks/gen",
 		Glob:        "*.txt",
 		WorkdirRoot: ".workdir/tasks/gen",
+		Setup:       envSetup,
 	})
 }
 
@@ -31,6 +38,7 @@ func TestKVFlow(t *testing.T) {
 		Dir:         "testdata/tasks/kv",
 		Glob:        "*.txt",
 		WorkdirRoot: ".workdir/tasks/kv",
+		Setup:       envSetup,
 	})
 }
 
@@ -40,6 +48,7 @@ func TestOSFlow(t *testing.T) {
 		Dir:         "testdata/tasks/os",
 		Glob:        "*.txt",
 		WorkdirRoot: ".workdir/tasks/os",
+		Setup:       envSetup,
 	})
 }
 
@@ -49,5 +58,6 @@ func TestStFlow(t *testing.T) {
 		Dir:         "testdata/tasks/st",
 		Glob:        "*.txt",
 		WorkdirRoot: ".workdir/tasks/st",
+		Setup:       envSetup,
 	})
 }
