@@ -5,8 +5,16 @@ import (
 	"path/filepath"
 )
 
-func FindModuleAbsPath() (string, error) {
-	dir, err := os.Getwd()
+func FindModuleAbsPath(dir string) (string, error) {
+	var err error
+	if dir == "" {
+		dir, err = os.Getwd()
+		if err != nil {
+			return "", err
+		}
+	}
+
+	dir, err = filepath.Abs(dir)
 	if err != nil {
 		return "", err
 	}
