@@ -2,6 +2,7 @@ package datamodel
 
 import (
 	"fmt"
+	"os"
 	"path/filepath"
 	"regexp"
 	"sort"
@@ -212,13 +213,25 @@ func loadDatamodelHistory(dm *Datamodel, crt *cuetils.CueRuntime) error {
 	}
 
 	// find module root
-	base, err := cuetils.FindModuleAbsPath()
+	base, err := cuetils.FindModuleAbsPath("")
 	if err != nil {
 		return err
 	}
 
+	// check basedir for existence before trying to load
+	basedir := filepath.Join(base, ".hof", "dm", dm.Name)
+	_, err = os.Lstat(basedir)
+	if err != nil {
+		if strings.Contains(err.Error(), "no such file or directory") {
+			return nil
+		}
+		return err
+	}
+
 	// get entrypoints
-	glob := filepath.Join(base, ".hof", "dm", dm.Name, "*.cue")
+	// todo, consider mapping these by output dir as well?
+	// (generally do we want to handle multiple data models with the same name?)
+	glob := filepath.Join(basedir, "*.cue")
 	entrypoints, err := zglob.Glob(glob)
 	if err != nil {
 		return err
@@ -231,6 +244,11 @@ func loadDatamodelHistory(dm *Datamodel, crt *cuetils.CueRuntime) error {
 		return err
 	}
 
+	// todo, need to think through no-history situations & processing
+	// check that value exists and has no errors? (shouldn't crt.Load() be doing some of this? why is it not catching the error earlier?)
+	// where downstream do we need to check?
+	// why does it fail when models are not nested, but ok when they are nested under top-level DM value
+
 	// iterate over fields (checkpoints)
 	vers := []*Datamodel{}
 	iter, err := crt.CueValue.Fields(cue.Attributes(true))
@@ -316,7 +334,7 @@ func loadDatamodelHistory(dm *Datamodel, crt *cuetils.CueRuntime) error {
 
 func FindHistoryBaseDir() (string, error) {
 	// try to find history
-	dir, err := cuetils.FindModuleAbsPath()
+	dir, err := cuetils.FindModuleAbsPath("")
 	if err != nil {
 		return "", err
 	}
