@@ -13,6 +13,9 @@ func envSetup(env *runtime.Env) error {
 	vars := []string{
 		"GITHUB_TOKEN",
 		"GITLAB_TOKEN",
+		"BITBUCKET_USERNAME",
+		"BITBUCKET_PASSWORD",
+		"HOFMOD_SSHKEY",
 	}
 	for _, v := range vars {
 		if val := os.Getenv(v); val != "" {
@@ -23,43 +26,52 @@ func envSetup(env *runtime.Env) error {
 	return nil
 }
 
+func setupWorkdir(dir string) {
+	os.RemoveAll(dir)
+	yagu.Mkdir(dir)
+}
+
 func TestModTests(t *testing.T) {
-	yagu.Mkdir(".workdir/tests")
+	d := ".workdir/tests"
+	setupWorkdir(d)
 	runtime.Run(t, runtime.Params{
 		Setup:       envSetup,
 		Dir:         "testdata",
 		Glob:        "*.txt",
-		WorkdirRoot: ".workdir/tests",
+		WorkdirRoot: d,
 	})
 }
 
 func TestModBugs(t *testing.T) {
-	yagu.Mkdir(".workdir/bugs")
+	d := ".workdir/bugs"
+	setupWorkdir(d)
 	runtime.Run(t, runtime.Params{
 		Setup:       envSetup,
 		Dir:         "testdata/bugs",
 		Glob:        "*.txt",
-		WorkdirRoot: ".workdir/bugs",
+		WorkdirRoot: d,
 	})
 }
 
 func TestModAuthdApikeysTests(t *testing.T) {
-	yagu.Mkdir(".workdir/authd/apikeys")
+	d := ".workdir/authd/apikeys"
+	setupWorkdir(d)
 	runtime.Run(t, runtime.Params{
 		Setup:       envSetup,
 		Dir:         "testdata/authd/apikeys",
 		Glob:        "*.txt",
-		WorkdirRoot: ".workdir/authd/apikeys",
+		WorkdirRoot: d,
 	})
 }
 
 func TestModAuthdSshconfigTests(t *testing.T) {
-	yagu.Mkdir(".workdir/authd/sshconfig")
+	d := ".workdir/authd/sshconfig"
+	setupWorkdir(d)
 	runtime.Run(t, runtime.Params{
 		Setup:       envSetup,
 		Dir:         "testdata/authd/sshconfig",
 		Glob:        "*.txt",
-		WorkdirRoot: ".workdir/authd/sshconfig",
+		WorkdirRoot: d,
 	})
 }
 
