@@ -8,8 +8,20 @@ import (
 	"strings"
 )
 
-func Bash(script string) (string, error) {
+func Shell(script, workdir string) (string, error) {
+	cmd := exec.Command("sh", "-c", script)
+	if workdir != "" {
+		cmd.Dir = workdir
+	}
+	out, err := cmd.CombinedOutput()
+	return string(out), err
+}
+
+func Bash(script, workdir string) (string, error) {
 	cmd := exec.Command("bash", "-p", "-c", script)
+	if workdir != "" {
+		cmd.Dir = workdir
+	}
 	out, err := cmd.CombinedOutput()
 	return string(out), err
 }
