@@ -1,8 +1,10 @@
 package yagu
 
 import (
+	"fmt"
 	"io/ioutil"
 	"os"
+	"path/filepath"
 	"strings"
 
 	"github.com/go-git/go-git/v5"
@@ -10,6 +12,61 @@ import (
 	"github.com/go-git/go-git/v5/plumbing/transport/http"
 )
 
+func FindGitRepoAbsPath(dir string) (string, error) {
+	var err error
+	if dir == "" {
+		dir, err = os.Getwd()
+		if err != nil {
+			return "", err
+		}
+	}
+
+	dir, err = filepath.Abs(dir)
+	if err != nil {
+		return "", err
+	}
+
+	found := false
+
+	for !found && dir != "/" {
+		try := filepath.Join(dir, ".git")
+		info, err := os.Stat(try)
+		if err == nil && info.IsDir() {
+			found = true
+			break
+		}
+
+		next := filepath.Clean(filepath.Join(dir, ".."))
+		dir = next
+	}
+
+	if !found {
+		return "", nil
+	}
+
+	return dir, nil
+}
+
+// FindRemoteRepoRootAndClone walks a path back until
+// it finds a valid git repo, cloning it into a tmp dir
+func FindRemoteRepoRootAndClone(repo, ver string) (root, dir string, err error) {
+	parts := strings.Split(repo, "/")
+	for i := len(parts); i > 1; i-- {
+		r := strings.Join(parts[:i], "/")
+		fmt.Println("trying...", r)
+		dir, err = CloneRepoIntoTmp("https://" + r, ver)
+		if err == nil {
+			return r, dir, nil
+		}
+		err = os.RemoveAll(dir)
+		if err != nil {
+			return r, dir, err
+		}
+	}
+
+	return "", "", fmt.Errorf("failed to find remote git repo from %s@%s", repo, ver)
+}
+
 func CloneRepoIntoTmp(srcUrl, srcVer string) (string, error) {
 
 	co, err := SetupGitOptions(srcUrl, srcVer)
